Module contours

Module contours 

Structs

Labelfont
Sets the font used for labeling the contour levels. The default color comes from the lines, if shown. The default family and size come from layout.font.

Enums

Coloring
Operation