Module indicator

Module indicator 

Modules

delta
gauge
number
title

Structs

Delta
Domain
Gauge
The gauge of the Indicator plot.
Indicator
An indicator is used to visualize a single value along with some contextual information such as steps or a threshold, using a combination of three visual elements: a number, a delta, and/or a gauge. Deltas are taken with respect to a reference. Gauges can be either angular or bullet (aka linear) gauges.
ModeFlags
Number
Stream
Title

Enums

Align
Mode
Visible