Module scattergl

Module scattergl 

Modules

hoverlabel
line
marker
selected
unselected

Structs

ErrorX
ErrorY
HoverinfoFlags
Hoverlabel
Line
Marker
ModeFlags
Scattergl
The data visualized as scatter point or lines is set in x and y using the WebGL plotting engine. Bubble charts are achieved by setting marker.size and/or marker.color to a numerical arrays.
Selected
Stream
Textfont
Sets the text font.
Unselected

Enums

Fill
Hoverinfo
Mode
Textposition
Visible
Xcalendar
Ycalendar