Module scattermapbox

Module scattermapbox 

Modules

hoverlabel
marker
selected
unselected

Structs

HoverinfoFlags
Hoverlabel
Line
Marker
ModeFlags
Scattermapbox
The data visualized as scatter point, lines or marker symbols on a Mapbox GL geographic map is provided by longitude/latitude pairs in lon and lat.
Selected
Stream
Textfont
Sets the icon text font (color=mapbox.layer.paint.text-color, size=mapbox.layer.layout.text-size). Has an effect only when type is set to symbol.
Unselected

Enums

Fill
Hoverinfo
Mode
Textposition
Visible